aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/gpu/GrAllocator.h
diff options
context:
space:
mode:
authorGravatar halcanary <halcanary@google.com>2015-08-27 07:41:13 -0700
committerGravatar Commit bot <commit-bot@chromium.org>2015-08-27 07:41:16 -0700
commit96fcdcc219d2a0d3579719b84b28bede76efba64 (patch)
tree0ec5ea0193d8292df8bf5ed9dd8498a5eb5763dd /src/gpu/GrAllocator.h
parent435af2f736c85c3274a0c6760a3523810750d237 (diff)
Style Change: NULL->nullptr
Diffstat (limited to 'src/gpu/GrAllocator.h')
-rw-r--r--src/gpu/GrAllocator.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gpu/GrAllocator.h b/src/gpu/GrAllocator.h
index 64f6533be4..c5d2dc3d38 100644
--- a/src/gpu/GrAllocator.h
+++ b/src/gpu/GrAllocator.h
@@ -29,7 +29,7 @@ public:
GrAllocator(size_t itemSize, int itemsPerBlock, void* initialBlock)
: fItemSize(itemSize)
, fItemsPerBlock(itemsPerBlock)
- , fOwnFirstBlock(NULL == initialBlock)
+ , fOwnFirstBlock(nullptr == initialBlock)
, fCount(0)
, fInsertionIndexInBlock(0) {
SkASSERT(itemsPerBlock > 0);
@@ -192,7 +192,7 @@ public:
protected:
/**
* Set first block of memory to write into. Must be called before any other methods.
* This requires that you have passed NULL in the constructor.
*
* @param initialBlock optional memory to use for the first block.
* Must be at least itemSize*itemsPerBlock sized.
@@ -237,7 +237,7 @@ public:
* @param itemsPerBlock the number of items to allocate at once
*/
explicit GrTAllocator(int itemsPerBlock)
- : fAllocator(sizeof(T), itemsPerBlock, NULL) {}
+ : fAllocator(sizeof(T), itemsPerBlock, nullptr) {}
/**
* Adds an item and returns it.
@@ -192,7 +192,7 @@ public:
/**
* Set first block of memory to write into. Must be called before any other methods.
- * This requires that you have passed NULL in the constructor.
+ * This requires that you have passed nullptr in the constructor.
*
* @param initialBlock optional memory to use for the first block.